# pylint: disable=too-many-function-args
# pylint: disable=multiple-imports
import sys, getopt
from nfl.user_login import open_main_page
from prompt_toolkit import prompt
from prompt_toolkit.shortcuts import set_title
from prompt_toolkit.validation import Validator


def is_valid_email(text):
    """_summary_

    Args:
        text (_type_): _description_

    Returns:
        _type_: _description_
    """
    return "@" in text


validator = Validator.from_callable(
    is_valid_email,
    error_message="Not a valid e-mail address (Does not contain an @).",
    move_cursor_to_end=True,
)

def main(args):
    """_summary_

    Args:
        args (_type_): _description_

    Returns:
        _type_: _description_
    """
    email = password = l_id = l_name = None
    verbose = True
    try:
        opts, args = getopt.getopt(args,"qhe:p:i:n",["email=","password=","id=","name="])
    except getopt.GetoptError:
        print('Issue with input validate your format is like below')
        print('main.py -e <email> -p <password> -i <id> -n <name> [-q]')
        sys.exit(2)
    for opt, arg in opts:
        if opt == '-h':
            print('NFL Scraper will scrap NFL.COM to get your league history. Ensure you use the format below. \n')
            print('main.py -e <email> -p <password> -i <id> -n <name> [-q]')
            sys.exit()
        elif opt == "-q":
            verbose = False
        elif opt in ("-e", "--email"):
            email = arg
        elif opt in ("-p", "--password"):
            password = arg
        elif opt in ("-i", "--id"):
            l_id = arg
        elif opt in ("-n", "--name"):
            l_name = arg
        else:
            print('main.py -e <email> -p <password> -i <id> -n <name> [-q]')
            print(f'{arg} unexpected, remove option and try again')
            sys.exit(1)
    if email is None:
        email = prompt("Enter e-mail address: ", validator=validator, validate_while_typing=False)
    if password is None:
        password = prompt("Password: ", is_password=True)
    if l_id is None:
        l_id = prompt("Input League Id: ")
    if l_name is None:
        l_name = prompt("Input the name of the league: ")
    open_main_page(email, password, l_id, l_name, verbose)
    return 1

if __name__ == "__main__":
    set_title("Enter nfl.com email, password, leaugeid, and any name")
    main(sys.argv[1:])



# This will not run on online IDE
# pylint: disable=invalid-name
# pylint: disable=consider-using-enumerate
from operator import contains
import requests
from utils.ff_models import *
from bs4 import BeautifulSoup
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
import jsonpickle


#TODO HIGH Add Output(json|excel) #json is done, but not part of a method
#TODO MED Make username, password, league id as inputs to module call
#TODO LOW Organize the methods a little better
#TODO VERY LOW I sort of want to utilize the objects in a web app for data manipulation/query

VERBOSE = True
def debug_print(message):
    """_summary_

    Args:
        message (_type_): _description_
    """
    if VERBOSE is True:
        print(message)

def get_driver():
    """_summary_

    Returns:
        _type_: _description_
    """
    options = webdriver.ChromeOptions()
    options.add_argument('--ignore-certificate-errors')
    options.add_argument('--incognito')
    #options.add_argument('--headless')
    return webdriver.Chrome("/usr/local/bin/chromedriver", chrome_options=options)

def open_main_page(username, password, leagueid, name, verbose) -> None:
    """Running this will run the entirety of the scrap. I've been using the debugger in 
    vscode
    """
    VERBOSE=verbose
    driver = get_driver()
    URL = "https://id.nfl.com/account/sign-in"
    driver.get(URL)
    debug_print(driver.title)
    driver.find_element("xpath","//input[@type='email']").send_keys(username)
    driver.find_element("xpath","//input[@type='password']").send_keys(password)
    button = WebDriverWait(driver, 100).until(EC.element_to_be_clickable((By.XPATH, "//div[@role='button' and @aria-label='Sign In button']")))
    button.click()
    league = League(name, leagueid)
    driver.implicitly_wait(3)
    debug_print(driver.title)
    URL = f"https://fantasy.nfl.com/league/{league.id}/history"
    driver.get(URL)
    ships(driver, league)
    single_game_points(driver, league)
    single_player_points_leader(driver, league)
    points_leader(driver, league)
    add_teams_to_seasons(driver, league)
    get_schedules_and_rosters(driver, league)
    with open("league_"+league.id+".json", "w") as write_file:
        write_file.write(str(jsonpickle.encode(league)))
    #TODO: Getting a key error with adding playoffs. Need to revisit.
    #The playoff games are recorded as part of the schedule above, so
    #technically, you could do some calculations on when the playoffs
    #started and track a team through playoff games, and record validation
    #until this is fixed, the game_types won't distinguish between playoff
    #and consolation games in  post season.
    #add_playoffs(driver, league)
    with open("league_"+league.id+".json", "w") as write_file:
        write_file.write(str(jsonpickle.encode(league)))

    
def ships(driver, league) -> None:
    """What it is all about, yachts and champagne

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    winner_rows = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[2]/div/div/div[1]/table/tbody/tr")
    debug_print("found")
    debug_print(str(len(winner_rows)))
    for x in range(len(winner_rows)):
        year = winner_rows[x].find_element("xpath",".//td[1]").text
        team = get_team(winner_rows[x], "3", [])
        ship = Championship(year)
        team.add_ship(ship)
        season = Season(year, team)
        league.update_season(season)
        debug_print(f"Year:{year} Name:{team.name} Id:{team.id}")
    debug_print(driver.title)
    
def single_game_points(driver, league) -> None:
    """Season Single Game Point Scoring leader

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    winner_rows = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[2]/div/div/div[2]/table/tbody/tr")
    debug_print("found")
    debug_print(str(len(winner_rows)))
    for x in range(len(winner_rows)):
        year = winner_rows[x].find_element("xpath",".//td[1]").text
        week = winner_rows[x].find_element("xpath",".//td[2]").text
        points = winner_rows[x].find_element("xpath",".//td[4]").text
        season = league.seasons[year]
        team = get_team(winner_rows[x], "3", season)
        season.set_highest_score(team.id, points, week)
        league.update_season(season)
        debug_print(f"Team:{team.name} Week:{season.highest_score_week} Score:{season.highest_score}")
    debug_print(driver.title)

def get_schedules_and_rosters(driver, league) -> None:
    """Adding each game directly to the individual team. It would be where
    I'd probably add rosters, but not messing with it atm

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    for year in league.seasons:
        season = league.seasons[year]
        for teamid in season.teams:
            #&gameSeason=year
            url = "https://fantasy.nfl.com/league/"+league.id+"/history/"+year+"/schedule?standingsTab=schedule&scheduleType=team&leagueId="+league.id+"&scheduleDetail="+teamid
            driver.get(url)
            #driver.implicitly_wait(2)
            team = season.teams[teamid]
            #Could pull userId from class, unless the user no longer exists
            team.set_manager(driver.find_element("xpath", "//a[contains(@class,'userName')]").text)
            #Currently the only table on page, trying out the //
            game_rows = driver.find_elements("xpath", "//table/tbody/tr")
            for x in range(len(game_rows)):
                try:
                    week = game_rows[x].find_element("xpath", ".//td[1]").text
                    opp_team = get_team(game_rows[x], "2", season)
                    score = game_rows[x].find_element("xpath", ".//td[3]/div/a/em[1]").text
                    opponent_score = game_rows[x].find_element("xpath", ".//td[3]/div/a/em[2]").text
                    debug_print(f"{team.name} vs {opp_team.name} was {score}-{opponent_score}")
                    team.add_game(Game(week, team.name, team.id, score, opp_team.id, opp_team.name, opponent_score, "regular"))
                except Exception:
                    #Honestly this is sort of a guess, it happens in playoffs
                    team.add_bye_week(game_rows[x].find_element("xpath", ".//td[1]").text)

def single_player_points_leader(driver, league) -> None:
    """I planned on added players, but it felt like overkill. At least each season point
    scorer is recorded to the season

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    winner_rows = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[2]/div/div/div[3]/table/tbody/tr")
    debug_print("found")
    debug_print(str(len(winner_rows)))
    for x in range(len(winner_rows)):
        year = winner_rows[x].find_element("xpath",".//td[1]").text
        week = winner_rows[x].find_element("xpath",".//td[2]").text
        points = winner_rows[x].find_element("xpath",".//td[5]").text
        player_name = winner_rows[x].find_element("xpath",".//td[4]/div/a").text
        player_pos_team = winner_rows[x].find_element("xpath",".//td[4]/div/em").text
        season = league.seasons[year]
        team = get_team(winner_rows[x], "3", season)
        season.set_highest_player_score(team.id, points, week, player_name, player_pos_team)
        league.update_season(season)
        debug_print(f"Team:{team.name} Week:{week} Score:{points} PlayerName: {player_name} PlayerPos: {player_pos_team}")
    debug_print(driver.title)


def points_leader(driver, league) -> None:
    """Points leader is a single team each season..unless there is a tie then
    this is f'd

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    winner_rows = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[2]/div/div/div[4]/table/tbody/tr")
    debug_print("found")
    debug_print(str(len(winner_rows)))
    for x in range(len(winner_rows)):
        year = winner_rows[x].find_element("xpath",".//td[1]").text
        points = winner_rows[x].find_element("xpath",".//td[4]").text
        season = league.seasons[year]
        team = get_team(winner_rows[x], "3", season)
        season.set_points_leader(team.id, points)
        league.update_season(season)
        debug_print(f"Team:{team.name} Score:{season.highest_score}")
    debug_print(driver.title)

def add_playoffs(driver, league) -> None:
    """The playoffs are weird animal so made it an array of games on the season,
    and added the games to each team that played in them. Could mess up something with
    teams having exta games. Adding a boolean for isPlayoffs if that distinction needs
    to be made

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    for year in league.seasons:
        season = league.seasons[year]
        url = "https://fantasy.nfl.com/league/"+league.id+"/history/"+year+"/playoffs"
        driver.get(url)
        playoff_weeks = driver.find_elements("xpath","//ul[@class='playoffContent']/li")
        for x in range(len(playoff_weeks)):
            week = playoff_weeks[x].find_element("xpath", ".//h4").text.replace("Week", "").strip()
            playoff_games = playoff_weeks[x].find_elements("xpath", ".//ul/li")
            for y in range(len(playoff_games)):
                week_title = playoff_games[y].find_element("xpath", ".//h5").text.strip()
                game_type = "consolation" if "final" not in week_title or "Bowl" not in week_title else "playoff"
                #playoff_games[y].find_element("xpath", ".//div/")
                team = get_team_from_a(playoff_games[y].find_element("xpath", ".//div/div[1]/div[1]/a"), season)
                score = playoff_games[y].find_element("xpath", ".//div/div[1]/div[2]").text
                opp_team = get_team_from_a(playoff_games[y].find_element("xpath", ".//div/div[2]/div[1]/a"), season)
                opp_score = playoff_games[y].find_element("xpath", ".//div/div[2]/div[2]").text
                playoff_game = Game(week, team.name, team.id, score, opp_team.id, opp_team.name, opp_score, game_type)
                season.add_playoff_game(playoff_game)
                debug_print(f"{team.name} vs {opp_team.name} was {score}-{opp_score}")
            #TODO: Consider ensuring any other games not in playoffs set as toilet bowl or something
        league.update_season(season)

def add_teams_to_seasons(driver, league) -> None:
    """Adding the teams individually to a season

    Args:
        driver (_type_): _description_
        league (_type_): _description_
    """
    for year in league.seasons:
        season = league.seasons[year]
        url = "https://fantasy.nfl.com/league/"+league.id+"/history/"+year+"/standings?historyStandingsType=regular"
        count_divisions = -1
        driver.get(url)
        #driver.implicitly_wait(3)
        try:
            divisions = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[5]/div/div/div[contains(@class,'hasDivisions')]")
            count_divisions = len(divisions) - 1
            if count_divisions == -1:
                count_divisions = 1
        except Exception:
            debug_print("add_teams_to_seasons potential error: "+year)
        
        for division_index in range(count_divisions):
            if count_divisions == 1:
                rows = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[5]/div/div/div[1]/table/tbody/tr")
                division = ""
            else:
                #Selenium doesn't zero index..gross
                rows = driver.find_elements("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[5]/div/div/div["+str(division_index+2)+"]/table/tbody/tr")
                division = driver.find_element("xpath","/html/body/div[1]/div[3]/div/div[1]/div/div[5]/div/div/div["+str(division_index+2)+"]/h5").text.split(':')[1].strip()
            team_count = len(rows)
            debug_print("current teams: " +str(len(season.teams)))
            for x in range(team_count):
                rank = rows[x].find_element("xpath",".//td[1]").text
                record = rows[x].find_element("xpath",".//td[3]").text
                points_for = rows[x].find_element("xpath",".//td[6]").text
                points_against = rows[x].find_element("xpath",".//td[7]").text
                team = get_team(rows[x], "2", season)
                if team.id in season.teams:
                    team = season.teams[team.id]
                team.add_record(record, points_for, points_against, rank, division)
                season.teams[team.id] = team
                debug_print(f"Team:{team.name} Points for: {points_for} Points Against:{points_against} Record: {record}")
            league.update_season(season)
        debug_print(driver.title)


def get_team(row, col, season, container = "td") -> Team:
    """Pulling the team name and id out of the expected column

    Args:
        row (_type_): _description_
        col (_type_): _description_
        season (_type_): _description_

    Returns:
        _type_: _description_
    """
    team_a = row.find_element("xpath",".//"+container+"["+col+"]/div/a[2]")
    return get_team_from_a(team_a, season)

def get_team_from_a(atag, season) -> Team:
    """_summary_

    Args:
        atag (_type_): _description_
        season (_type_): _description_

    Returns:
        _type_: _description_
    """
    team_id = atag.get_attribute("href").split('/')[-1]
    # Into earlier seasons the urls were a bit different
    if "teamId=" in team_id:
        team_id = team_id.split('teamId=')[1]
    try:
        return season.teams[team_id]
    except Exception:
        return Team(team_id, atag.text)

def main_page() -> None:
    """_summary_
    """
    URL = "https://id.nfl.com/account/sign-in?authReturnUrl=https%3A%2F%2Fid.nfl.com%2Faccount"
    headers = {'User-Agent': "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.2311.135 Safari/537.36 Edge/12.246"}
    r = requests.get(url=URL, headers=headers)
    #r = requests.get(URL)
    
    soup = BeautifulSoup(r.content, 'html5lib') # If this line causes an error, run 'pip install html5lib' or install html5lib
    debug_print(soup.prettify())
    # Here the user agent is for Edge browser on windows 10. You can find your browser user agent from the above given link.




class League:
    """_summary_
    """
    def __init__(self, league_name, league_id):
        self.seasons = {}
        self.league_name = league_name
        self.id = league_id
    def get_season(self, year):
        """_summary_

        Args:
            year (_type_): _description_

        Returns:
            _type_: _description_
        """
        return self.seasons[year]
    def update_season(self, season):
        """_summary_

        Args:
            season (_type_): _description_
        """
        
        self.seasons[season.year] = season
    def get_team(self, id, year = None):
        """_summary_

        Args:
            id (_type_): _description_
            year (_type_, optional): _description_. Defaults to None.

        Returns:
            _type_: _description_
        """
        if year is not None and self.seasons[year]:
            if id in self.seasons[year].teams:
                return dict(self.seasons[year].teams[id])
            else:
                print(f"Team with {id} in year {year} does not exist")
        elif year is None:
            team_seasons = dict()
            for season in self.seasons:
                if season.teams[id]:
                    team_seasons[season.id] = season.teams[id]
            return team_seasons
        else:
            print(f"Team with {id} was not found in any league")
class Game:
    """Game
    """
    def __init__(self, week, name, id, score, opponent_id, opponent_name, opponent_score, game_type = "regular"):
        """_summary_

        Args:
            week (_type_): _description_
            name (_type_): _description_
            id (_type_): _description_
            score (_type_): _description_
            opponent_id (_type_): _description_
            opponent_name (_type_): _description_
            opponent_score (_type_): _description_
            game_type (str, optional): _description_. Defaults to "regular".
        """
        self.week = week
        self.score = score
        self.opponent_id = opponent_id
        self.opponent_score = opponent_score
        self.opponent_name = opponent_name
        self.name = name
        self.id = id
        self.game_type = game_type
        
    def set_playoffs(self, game_type):
        """_summary_

        Args:
            game_type (_type_): _description_
        """
        self.game_type = game_type
class Team:
    """_summary_
    """
    def __init__(self, id, name):
        self.name = name
        self.id = id
        self.owner=""
        self.championships = {}
        self.total_points = 0
        self.total_points_against = 0
        self.wins = 0
        self.losses = 0
        self.rank = 0
        self.ties = 0
        self.division = ""
        self.games = dict()
        self.manager = ""
    def set_manager(self, manager):
        """_summary_

        Args:
            manager (_type_): _description_
        """
        self.manager = manager
    
    def add_ship(self, championship):
        """_summary_

        Args:
            championship (_type_): _description_
        """
        self.championships[championship.year] = championship
    def add_total_points(self, points):
        """_summary_

        Args:
            points (_type_): _description_
        """
        self.total_points = points
    def add_game(self, game):
        """Add a game to a team

        Args:
            game (_type_): _description_
        """
        self.games[game.week] = game
    def add_bye_week(self, week):
        """Right now this is used when catching any errors while building the schedule
        it should be a playoff bye week, but if other games pop up under this, check it out
        """
        game = Game(week, self.name, self.id, "0", "0", "bye", "0", "bye") #, True) #If you want to default to playoffs
        self.games[week] = game
    def add_record(self, win_loss_tie, total_point, total_points_against, rank, division=""):
        """_summary_

        Args:
            win_loss_ tie (_type_): _description_
        """
        wlt = win_loss_tie.split('-')
        self.wins = wlt[0]
        self.losses = wlt[1]
        self.ties = wlt[2]
        self.rank = rank
        self.total_points = total_point
        self.total_points_against = total_points_against
        self.division = division

class Season:
    """_summary_
    """
    def __init__(self, year, team):
        self.year = year
        self.teams = dict()
        self.teams[team.id]=team
        self.highest_score = 0
        self.highest_score_team_id = 0
        self.highest_score_week = 0
        self.points_leader_total = 0
        self.points_leader_team_id = 0
        self.highest_player_team_id = 0
        self.highest_player_points = 0
        self.highest_player_week = 0
        self.highest_player_name = ""
        self.highest_player_pos_team = ""
        self.playoffs = []
    def add_team(self, team):
        """_summary_

        Args:
            team (_type_): _description_
        """
        self.teams[team.id]=team
    def add_playoff_game(self, game):
        """_summary_

        Args:
            game (_type_): _description_
        """
        self.playoffs.append(game)
        #double check a_team, and b_team don't need to be updated on season
        self.teams[game.id].games[game.week].set_playoffs(game.game_type)
        self.teams[game.opponent_id].games[game.week].set_playoffs(game.game_type)

    def set_highest_score(self, team_id, score, week):
        """_summary_

        Args:
            team (_type_): _description_
            score (_type_): _description_
            week (_type_): _description_
        """
        self.highest_score = score
        self.highest_score_team_id = team_id
        self.highest_score_week = week
    def set_points_leader(self, team_id, points):
        """_summary_

        Args:
            team (_type_): _description_
            points (_type_): _description_
        """
        self.points_leader_total = points
        self.points_leader_team_id = team_id
    def set_highest_player_score(self, team_id, points, week, player_name, pos_team):
        """_summary_

        Args:
            team (_type_): _description_
            points (_type_): _description_
            week (_type_): _description_
            player_name (_type_): _description_
            pos_team (_type_): _description_
        """
        self.highest_player_team_id = team_id
        self.highest_player_points = points
        self.highest_player_week = week
        self.highest_player_name = player_name
        self.highest_player_pos_team = pos_team
class Championship:
    """_summary_
    """
    def __init__(self, year):
        self.year = year


#https://www98.myfantasyleague.com/2007/home/68870
#https://www98.myfantasyleague.com/2008/home/44144
#https://www98.myfantasyleague.com/2009/home/37190
#https://www98.myfantasyleague.com/2007/home/34836



from __future__ import annotations

import sys

from contextlib import suppress


# TODO: use try/except ImportError when
# https://github.com/python/mypy/issues/1393 is fixed
if sys.version_info < (3, 10):
    # compatibility for python <3.10
    import importlib_metadata as metadata
else:
    from importlib import metadata

WINDOWS = sys.platform == "win32"


def decode(string: bytes | str, encodings: list[str] | None = None) -> str:
    if not isinstance(string, bytes):
        return string

    encodings = encodings or ["utf-8", "latin1", "ascii"]

    for encoding in encodings:
        with suppress(UnicodeEncodeError, UnicodeDecodeError):
            return string.decode(encoding)

    return string.decode(encodings[0], errors="ignore")


def encode(string: str, encodings: list[str] | None = None) -> bytes:
    if isinstance(string, bytes):
        return string

    encodings = encodings or ["utf-8", "latin1", "ascii"]

    for encoding in encodings:
        with suppress(UnicodeEncodeError, UnicodeDecodeError):
            return string.encode(encoding)

    return string.encode(encodings[0], errors="ignore")


def to_str(string: str) -> str:
    return decode(string)


def list_to_shell_command(cmd: list[str]) -> str:
    return " ".join(
        f'"{token}"' if " " in token and token[0] not in {"'", '"'} else token
        for token in cmd
    )


__all__ = ["WINDOWS", "decode", "encode", "list_to_shell_command", "metadata", "to_str"]


# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['nfl_scraper',
 'nfl_scraper.my_fantasy',
 'nfl_scraper.nfl',
 'nfl_scraper.utils']

package_data = \
{'': ['*'],
 'nfl_scraper': ['.pytest_cache/*', '.pytest_cache/v/cache/*', 'dist/*']}

install_requires = \
['bs4>=0.0.1,<0.0.2',
 'html5lib>=1.1,<2.0',
 'jsonpickle>=2.2.0,<3.0.0',
 'prompt-toolkit>=3.0.30,<4.0.0',
 'requests>=2.28.1,<3.0.0',
 'selenium>=4.3.0,<5.0.0']

extras_require = \
{':python_version < "3.10"': ['importlib-metadata>=4.4,<5.0']}

setup_kwargs = {
    'name': 'nfl-scraper',
    'version': '1.0.1',
    'description': 'Creating a scraper for multiple fantasy football sites',
    'long_description': '# fantasy-scraper\nTrying to scrape all data from our fantasy league with NFL.com. Since we are moving to Sleeper. It might end up include myfantasyleague as well\n\n\n## Pipenv and Poetry\n\nSetup\n\n```bash\ncurl -sSL https://instcurl -sSL https://install.python-poetry.org | python3 -\npipenv install --python=/usr/loca/bin/python3.10\npipenv shell\npoetry completions bash >> ~/.bash_completion\n#export PIP_PYTHON_PATH="$VIRTUAL_ENV/bin/python3"\npoetry new nfl_scraper\npoetry new nfl_scraper\n#pipenv install --index=pip\n#pipenv install --index=distutils\npoetry add requests\npoetry add html5lib\npoetry add bs4\n\n\n#pip uninstall -y setuptools\n#exit\n#deactivate \n```\n\n## Running as Non Dev\n\n```shell\npoetry install --without dev --sync\npoetry run python -V\n# Help\npoetry run python main.py -h \n# Sub out the params\npoetry run python main.py -e <email> -p <password> -i <id> -n <name>\n# Test need to beef these up\npoetry run pytest\n```\n\n## Running as Dev\n\n```shell\npoetry check\npoetry build\n#poetry update #gets latest package version\n\n```\n\n## Running in CICD\n\n```shell\npoetry check\n# output version\npoetry version -s\n\npoetry version major|minor|patch --dry-run\n```\n',
    'author': 'DeadlyChambers',
    'author_email': 'shanechambers85@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/DeadlyChambers/fantasy-scraper',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
